Tools for the Piksi GNSS receiver
=================================

Python tools for the Piksi GNSS receiver.

Setup
-----

Install dependencies only::

  $ sudo pip install -r requirements.txt

Install from repo::

  $ sudo pip setup.py install

Install package from pypi::

  $ sudo pip install piksi_tools

Usage Examples
--------------

Bootloader example
~~~~~~~~~~~~~~~~~~

Something cool.

Console example
~~~~~~~~~~~~~~~

Something cooler.

Testing
-------

To run the tests and check for coverage::

  $  py.test -v --cov piksi_tools tests/

License
-------

Copyright © 2015 Swift Navigation

Distributed under LGPLv3.0.
